# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/asset_v1beta1/proto/asset_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.asset_v1beta1.proto import assets_pb2 as google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_assets__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/cloud/asset_v1beta1/proto/asset_service.proto',
  package='google.cloud.asset.v1beta1',
  syntax='proto3',
  serialized_pb=_b('\n4google/cloud/asset_v1beta1/proto/asset_service.proto\x12\x1agoogle.cloud.asset.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a-google/cloud/asset_v1beta1/proto/assets.proto\x1a#google/longrunning/operations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe9\x01\n\x13\x45xportAssetsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12-\n\tread_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x61sset_types\x18\x03 \x03(\t\x12=\n\x0c\x63ontent_type\x18\x04 \x01(\x0e\x32\'.google.cloud.asset.v1beta1.ContentType\x12?\n\routput_config\x18\x05 \x01(\x0b\x32(.google.cloud.asset.v1beta1.OutputConfig\"\x86\x01\n\x14\x45xportAssetsResponse\x12-\n\tread_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\routput_config\x18\x02 \x01(\x0b\x32(.google.cloud.asset.v1beta1.OutputConfig\"\xc4\x01\n\x1c\x42\x61tchGetAssetsHistoryRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x13\n\x0b\x61sset_names\x18\x02 \x03(\t\x12=\n\x0c\x63ontent_type\x18\x03 \x01(\x0e\x32\'.google.cloud.asset.v1beta1.ContentType\x12@\n\x10read_time_window\x18\x04 \x01(\x0b\x32&.google.cloud.asset.v1beta1.TimeWindow\"Z\n\x1d\x42\x61tchGetAssetsHistoryResponse\x12\x39\n\x06\x61ssets\x18\x01 \x03(\x0b\x32).google.cloud.asset.v1beta1.TemporalAsset\"d\n\x0cOutputConfig\x12\x45\n\x0fgcs_destination\x18\x01 \x01(\x0b\x32*.google.cloud.asset.v1beta1.GcsDestinationH\x00\x42\r\n\x0b\x64\x65stination\"\x1d\n\x0eGcsDestination\x12\x0b\n\x03uri\x18\x01 \x01(\t*I\n\x0b\x43ontentType\x12\x1c\n\x18\x43ONTENT_TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08RESOURCE\x10\x01\x12\x0e\n\nIAM_POLICY\x10\x02\x32\xdf\x03\n\x0c\x41ssetService\x12\xc9\x01\n\x0c\x45xportAssets\x12/.google.cloud.asset.v1beta1.ExportAssetsRequest\x1a\x1d.google.longrunning.Operation\"i\x82\xd3\xe4\x93\x02\x63\")/v1beta1/{parent=projects/*}:exportAssets:\x01*Z3\"./v1beta1/{parent=organizations/*}:exportAssets:\x01*\x12\x82\x02\n\x15\x42\x61tchGetAssetsHistory\x12\x38.google.cloud.asset.v1beta1.BatchGetAssetsHistoryRequest\x1a\x39.google.cloud.asset.v1beta1.BatchGetAssetsHistoryResponse\"t\x82\xd3\xe4\x93\x02n\x12\x32/v1beta1/{parent=projects/*}:batchGetAssetsHistoryZ8\x12\x36/v1beta1/{parent=organizations/*}:batchGetAssetHistoryB\xb0\x01\n\x1e\x63om.google.cloud.asset.v1beta1B\x11\x41ssetServiceProtoP\x01Z?google.golang.org/genproto/googleapis/cloud/asset/v1beta1;asset\xaa\x02\x1aGoogle.Cloud.Asset.V1Beta1\xca\x02\x1aGoogle\\Cloud\\Asset\\V1beta1b\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_assets__pb2.DESCRIPTOR,google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_CONTENTTYPE = _descriptor.EnumDescriptor(
  name='ContentType',
  full_name='google.cloud.asset.v1beta1.ContentType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONTENT_TYPE_UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESOURCE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IAM_POLICY', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1028,
  serialized_end=1101,
)
_sym_db.RegisterEnumDescriptor(_CONTENTTYPE)

ContentType = enum_type_wrapper.EnumTypeWrapper(_CONTENTTYPE)
CONTENT_TYPE_UNSPECIFIED = 0
RESOURCE = 1
IAM_POLICY = 2



_EXPORTASSETSREQUEST = _descriptor.Descriptor(
  name='ExportAssetsRequest',
  full_name='google.cloud.asset.v1beta1.ExportAssetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='google.cloud.asset.v1beta1.ExportAssetsRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_time', full_name='google.cloud.asset.v1beta1.ExportAssetsRequest.read_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset_types', full_name='google.cloud.asset.v1beta1.ExportAssetsRequest.asset_types', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='google.cloud.asset.v1beta1.ExportAssetsRequest.content_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_config', full_name='google.cloud.asset.v1beta1.ExportAssetsRequest.output_config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=465,
)


_EXPORTASSETSRESPONSE = _descriptor.Descriptor(
  name='ExportAssetsResponse',
  full_name='google.cloud.asset.v1beta1.ExportAssetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='read_time', full_name='google.cloud.asset.v1beta1.ExportAssetsResponse.read_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_config', full_name='google.cloud.asset.v1beta1.ExportAssetsResponse.output_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=468,
  serialized_end=602,
)


_BATCHGETASSETSHISTORYREQUEST = _descriptor.Descriptor(
  name='BatchGetAssetsHistoryRequest',
  full_name='google.cloud.asset.v1beta1.BatchGetAssetsHistoryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent', full_name='google.cloud.asset.v1beta1.BatchGetAssetsHistoryRequest.parent', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset_names', full_name='google.cloud.asset.v1beta1.BatchGetAssetsHistoryRequest.asset_names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='google.cloud.asset.v1beta1.BatchGetAssetsHistoryRequest.content_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='read_time_window', full_name='google.cloud.asset.v1beta1.BatchGetAssetsHistoryRequest.read_time_window', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=605,
  serialized_end=801,
)


_BATCHGETASSETSHISTORYRESPONSE = _descriptor.Descriptor(
  name='BatchGetAssetsHistoryResponse',
  full_name='google.cloud.asset.v1beta1.BatchGetAssetsHistoryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='assets', full_name='google.cloud.asset.v1beta1.BatchGetAssetsHistoryResponse.assets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=803,
  serialized_end=893,
)


_OUTPUTCONFIG = _descriptor.Descriptor(
  name='OutputConfig',
  full_name='google.cloud.asset.v1beta1.OutputConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gcs_destination', full_name='google.cloud.asset.v1beta1.OutputConfig.gcs_destination', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='destination', full_name='google.cloud.asset.v1beta1.OutputConfig.destination',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=895,
  serialized_end=995,
)


_GCSDESTINATION = _descriptor.Descriptor(
  name='GcsDestination',
  full_name='google.cloud.asset.v1beta1.GcsDestination',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='google.cloud.asset.v1beta1.GcsDestination.uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=997,
  serialized_end=1026,
)

_EXPORTASSETSREQUEST.fields_by_name['read_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPORTASSETSREQUEST.fields_by_name['content_type'].enum_type = _CONTENTTYPE
_EXPORTASSETSREQUEST.fields_by_name['output_config'].message_type = _OUTPUTCONFIG
_EXPORTASSETSRESPONSE.fields_by_name['read_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXPORTASSETSRESPONSE.fields_by_name['output_config'].message_type = _OUTPUTCONFIG
_BATCHGETASSETSHISTORYREQUEST.fields_by_name['content_type'].enum_type = _CONTENTTYPE
_BATCHGETASSETSHISTORYREQUEST.fields_by_name['read_time_window'].message_type = google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_assets__pb2._TIMEWINDOW
_BATCHGETASSETSHISTORYRESPONSE.fields_by_name['assets'].message_type = google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_assets__pb2._TEMPORALASSET
_OUTPUTCONFIG.fields_by_name['gcs_destination'].message_type = _GCSDESTINATION
_OUTPUTCONFIG.oneofs_by_name['destination'].fields.append(
  _OUTPUTCONFIG.fields_by_name['gcs_destination'])
_OUTPUTCONFIG.fields_by_name['gcs_destination'].containing_oneof = _OUTPUTCONFIG.oneofs_by_name['destination']
DESCRIPTOR.message_types_by_name['ExportAssetsRequest'] = _EXPORTASSETSREQUEST
DESCRIPTOR.message_types_by_name['ExportAssetsResponse'] = _EXPORTASSETSRESPONSE
DESCRIPTOR.message_types_by_name['BatchGetAssetsHistoryRequest'] = _BATCHGETASSETSHISTORYREQUEST
DESCRIPTOR.message_types_by_name['BatchGetAssetsHistoryResponse'] = _BATCHGETASSETSHISTORYRESPONSE
DESCRIPTOR.message_types_by_name['OutputConfig'] = _OUTPUTCONFIG
DESCRIPTOR.message_types_by_name['GcsDestination'] = _GCSDESTINATION
DESCRIPTOR.enum_types_by_name['ContentType'] = _CONTENTTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExportAssetsRequest = _reflection.GeneratedProtocolMessageType('ExportAssetsRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXPORTASSETSREQUEST,
  __module__ = 'google.cloud.asset_v1beta1.proto.asset_service_pb2'
  ,
  __doc__ = """Export asset request.
  
  
  Attributes:
      parent:
          Required. The relative name of the root asset. Can only be an
          organization number (such as "organizations/123"), or a
          project id (such as "projects/my-project-id") or a project
          number (such as "projects/12345").
      read_time:
          Timestamp to take an asset snapshot. This can only be set to a
          timestamp in the past or of the current time. If not
          specified, the current time will be used. Due to delays in
          resource data collection and indexing, there is a volatile
          window during which running the same query may get different
          results.
      asset_types:
          A list of asset types of which to take a snapshot for.
          Example: "google.compute.disk". If specified, only matching
          assets will be returned.
      content_type:
          Asset content type. If not specified, no content but the asset
          name will be returned.
      output_config:
          Required. Output configuration indicating where the results
          will be output to. All results will be in newline delimited
          JSON format.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.ExportAssetsRequest)
  ))
_sym_db.RegisterMessage(ExportAssetsRequest)

ExportAssetsResponse = _reflection.GeneratedProtocolMessageType('ExportAssetsResponse', (_message.Message,), dict(
  DESCRIPTOR = _EXPORTASSETSRESPONSE,
  __module__ = 'google.cloud.asset_v1beta1.proto.asset_service_pb2'
  ,
  __doc__ = """The export asset response. This message is returned by the
  [google.longrunning.Operations.GetOperation][google.longrunning.Operations.GetOperation]
  method in the returned
  [google.longrunning.Operation.response][google.longrunning.Operation.response]
  field.
  
  
  Attributes:
      read_time:
          Time the snapshot was taken.
      output_config:
          Output configuration indicating where the results were output
          to. All results are in JSON format.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.ExportAssetsResponse)
  ))
_sym_db.RegisterMessage(ExportAssetsResponse)

BatchGetAssetsHistoryRequest = _reflection.GeneratedProtocolMessageType('BatchGetAssetsHistoryRequest', (_message.Message,), dict(
  DESCRIPTOR = _BATCHGETASSETSHISTORYREQUEST,
  __module__ = 'google.cloud.asset_v1beta1.proto.asset_service_pb2'
  ,
  __doc__ = """Batch get assets history request.
  
  
  Attributes:
      parent:
          Required. The relative name of the root asset. It can only be
          an organization number (such as "organizations/123"), or a
          project id (such as "projects/my-project-id")"or a project
          number (such as "projects/12345").
      asset_names:
          A list of the full names of the assets. See: https://cloud.goo
          gle.com/apis/design/resource\_names#full\_resource\_name
          Example: "//compute.googleapis.com/projects/my\_project\_123/z
          ones/zone1/instances/instance1".  The request becomes a no-op
          if the asset name list is empty, and the max size of the asset
          name list is 100 in one request.
      content_type:
          Required. The content type.
      read_time_window:
          Required. The time window for the asset history. The start
          time is required. The returned results contain all temporal
          assets whose time window overlap with read\_time\_window.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.BatchGetAssetsHistoryRequest)
  ))
_sym_db.RegisterMessage(BatchGetAssetsHistoryRequest)

BatchGetAssetsHistoryResponse = _reflection.GeneratedProtocolMessageType('BatchGetAssetsHistoryResponse', (_message.Message,), dict(
  DESCRIPTOR = _BATCHGETASSETSHISTORYRESPONSE,
  __module__ = 'google.cloud.asset_v1beta1.proto.asset_service_pb2'
  ,
  __doc__ = """Batch get assets history response.
  
  
  Attributes:
      assets:
          A list of assets with valid time windows.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.BatchGetAssetsHistoryResponse)
  ))
_sym_db.RegisterMessage(BatchGetAssetsHistoryResponse)

OutputConfig = _reflection.GeneratedProtocolMessageType('OutputConfig', (_message.Message,), dict(
  DESCRIPTOR = _OUTPUTCONFIG,
  __module__ = 'google.cloud.asset_v1beta1.proto.asset_service_pb2'
  ,
  __doc__ = """Output configuration for export assets destination.
  
  
  Attributes:
      destination:
          Asset export destination.
      gcs_destination:
          Destination on Google Cloud Storage (GCS).
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.OutputConfig)
  ))
_sym_db.RegisterMessage(OutputConfig)

GcsDestination = _reflection.GeneratedProtocolMessageType('GcsDestination', (_message.Message,), dict(
  DESCRIPTOR = _GCSDESTINATION,
  __module__ = 'google.cloud.asset_v1beta1.proto.asset_service_pb2'
  ,
  __doc__ = """A Google Cloud Storage (GCS) location.
  
  
  Attributes:
      uri:
          The path of the GCS objects. It's the same path that is used
          by gsutil, for example: "gs://bucket\_name/object\_path". See:
          https://cloud.google.com/storage/docs/viewing-editing-metadata
          for more information.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.GcsDestination)
  ))
_sym_db.RegisterMessage(GcsDestination)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\036com.google.cloud.asset.v1beta1B\021AssetServiceProtoP\001Z?google.golang.org/genproto/googleapis/cloud/asset/v1beta1;asset\252\002\032Google.Cloud.Asset.V1Beta1\312\002\032Google\\Cloud\\Asset\\V1beta1'))

_ASSETSERVICE = _descriptor.ServiceDescriptor(
  name='AssetService',
  full_name='google.cloud.asset.v1beta1.AssetService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=1104,
  serialized_end=1583,
  methods=[
  _descriptor.MethodDescriptor(
    name='ExportAssets',
    full_name='google.cloud.asset.v1beta1.AssetService.ExportAssets',
    index=0,
    containing_service=None,
    input_type=_EXPORTASSETSREQUEST,
    output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002c\")/v1beta1/{parent=projects/*}:exportAssets:\001*Z3\"./v1beta1/{parent=organizations/*}:exportAssets:\001*')),
  ),
  _descriptor.MethodDescriptor(
    name='BatchGetAssetsHistory',
    full_name='google.cloud.asset.v1beta1.AssetService.BatchGetAssetsHistory',
    index=1,
    containing_service=None,
    input_type=_BATCHGETASSETSHISTORYREQUEST,
    output_type=_BATCHGETASSETSHISTORYRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002n\0222/v1beta1/{parent=projects/*}:batchGetAssetsHistoryZ8\0226/v1beta1/{parent=organizations/*}:batchGetAssetHistory')),
  ),
])
_sym_db.RegisterServiceDescriptor(_ASSETSERVICE)

DESCRIPTOR.services_by_name['AssetService'] = _ASSETSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/asset_v1beta1/proto/assets.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.iam.v1 import iam_policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/cloud/asset_v1beta1/proto/assets.proto',
  package='google.cloud.asset.v1beta1',
  syntax='proto3',
  serialized_pb=_b('\n-google/cloud/asset_v1beta1/proto/assets.proto\x12\x1agoogle.cloud.asset.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x1agoogle/iam/v1/policy.proto\x1a\x19google/protobuf/any.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8a\x01\n\rTemporalAsset\x12\x36\n\x06window\x18\x01 \x01(\x0b\x32&.google.cloud.asset.v1beta1.TimeWindow\x12\x0f\n\x07\x64\x65leted\x18\x02 \x01(\x08\x12\x30\n\x05\x61sset\x18\x03 \x01(\x0b\x32!.google.cloud.asset.v1beta1.Asset\"j\n\nTimeWindow\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8c\x01\n\x05\x41sset\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\nasset_type\x18\x02 \x01(\t\x12\x36\n\x08resource\x18\x03 \x01(\x0b\x32$.google.cloud.asset.v1beta1.Resource\x12)\n\niam_policy\x18\x04 \x01(\x0b\x32\x15.google.iam.v1.Policy\"\xa0\x01\n\x08Resource\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x1e\n\x16\x64iscovery_document_uri\x18\x02 \x01(\t\x12\x16\n\x0e\x64iscovery_name\x18\x03 \x01(\t\x12\x14\n\x0cresource_url\x18\x04 \x01(\t\x12\x0e\n\x06parent\x18\x05 \x01(\t\x12%\n\x04\x64\x61ta\x18\x06 \x01(\x0b\x32\x17.google.protobuf.StructB\xa9\x01\n\x1e\x63om.google.cloud.asset.v1beta1B\nAssetProtoP\x01Z?google.golang.org/genproto/googleapis/cloud/asset/v1beta1;asset\xaa\x02\x1aGoogle.Cloud.Asset.V1Beta1\xca\x02\x1aGoogle\\Cloud\\Asset\\V1beta1b\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_iam_dot_v1_dot_policy__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_TEMPORALASSET = _descriptor.Descriptor(
  name='TemporalAsset',
  full_name='google.cloud.asset.v1beta1.TemporalAsset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='window', full_name='google.cloud.asset.v1beta1.TemporalAsset.window', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deleted', full_name='google.cloud.asset.v1beta1.TemporalAsset.deleted', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset', full_name='google.cloud.asset.v1beta1.TemporalAsset.asset', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=364,
)


_TIMEWINDOW = _descriptor.Descriptor(
  name='TimeWindow',
  full_name='google.cloud.asset.v1beta1.TimeWindow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time', full_name='google.cloud.asset.v1beta1.TimeWindow.start_time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='google.cloud.asset.v1beta1.TimeWindow.end_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=472,
)


_ASSET = _descriptor.Descriptor(
  name='Asset',
  full_name='google.cloud.asset.v1beta1.Asset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='google.cloud.asset.v1beta1.Asset.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='asset_type', full_name='google.cloud.asset.v1beta1.Asset.asset_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource', full_name='google.cloud.asset.v1beta1.Asset.resource', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='iam_policy', full_name='google.cloud.asset.v1beta1.Asset.iam_policy', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=475,
  serialized_end=615,
)


_RESOURCE = _descriptor.Descriptor(
  name='Resource',
  full_name='google.cloud.asset.v1beta1.Resource',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='google.cloud.asset.v1beta1.Resource.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='discovery_document_uri', full_name='google.cloud.asset.v1beta1.Resource.discovery_document_uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='discovery_name', full_name='google.cloud.asset.v1beta1.Resource.discovery_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_url', full_name='google.cloud.asset.v1beta1.Resource.resource_url', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent', full_name='google.cloud.asset.v1beta1.Resource.parent', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='google.cloud.asset.v1beta1.Resource.data', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=618,
  serialized_end=778,
)

_TEMPORALASSET.fields_by_name['window'].message_type = _TIMEWINDOW
_TEMPORALASSET.fields_by_name['asset'].message_type = _ASSET
_TIMEWINDOW.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TIMEWINDOW.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ASSET.fields_by_name['resource'].message_type = _RESOURCE
_ASSET.fields_by_name['iam_policy'].message_type = google_dot_iam_dot_v1_dot_policy__pb2.google_dot_iam_dot_v1_dot_policy__pb2._POLICY
_RESOURCE.fields_by_name['data'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['TemporalAsset'] = _TEMPORALASSET
DESCRIPTOR.message_types_by_name['TimeWindow'] = _TIMEWINDOW
DESCRIPTOR.message_types_by_name['Asset'] = _ASSET
DESCRIPTOR.message_types_by_name['Resource'] = _RESOURCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TemporalAsset = _reflection.GeneratedProtocolMessageType('TemporalAsset', (_message.Message,), dict(
  DESCRIPTOR = _TEMPORALASSET,
  __module__ = 'google.cloud.asset_v1beta1.proto.assets_pb2'
  ,
  __doc__ = """Temporal asset. In addition to the asset, the temporal asset includes
  the status of the asset and valid from and to time of it.
  
  
  Attributes:
      window:
          The time window when the asset data and state was observed.
      deleted:
          If the asset is deleted or not.
      asset:
          Asset.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.TemporalAsset)
  ))
_sym_db.RegisterMessage(TemporalAsset)

TimeWindow = _reflection.GeneratedProtocolMessageType('TimeWindow', (_message.Message,), dict(
  DESCRIPTOR = _TIMEWINDOW,
  __module__ = 'google.cloud.asset_v1beta1.proto.assets_pb2'
  ,
  __doc__ = """A time window of [start\_time, end\_time).
  
  
  Attributes:
      start_time:
          Start time of the time window (inclusive).
      end_time:
          End time of the time window (exclusive). Current timestamp if
          not specified.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.TimeWindow)
  ))
_sym_db.RegisterMessage(TimeWindow)

Asset = _reflection.GeneratedProtocolMessageType('Asset', (_message.Message,), dict(
  DESCRIPTOR = _ASSET,
  __module__ = 'google.cloud.asset_v1beta1.proto.assets_pb2'
  ,
  __doc__ = """Cloud asset. This include all Google Cloud Platform resources, as well
  as IAM policies and other non-GCP assets.
  
  
  Attributes:
      name:
          The full name of the asset. See: https://cloud.google.com/apis
          /design/resource\_names#full\_resource\_name Example: "//compu
          te.googleapis.com/projects/my\_project\_123/zones/zone1/instan
          ces/instance1".
      asset_type:
          Type of the asset. Example: "google.compute.disk".
      resource:
          Representation of the resource.
      iam_policy:
          Representation of the actual IAM policy set on a cloud
          resource. For each resource, there must be at most one IAM
          policy set on it.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.Asset)
  ))
_sym_db.RegisterMessage(Asset)

Resource = _reflection.GeneratedProtocolMessageType('Resource', (_message.Message,), dict(
  DESCRIPTOR = _RESOURCE,
  __module__ = 'google.cloud.asset_v1beta1.proto.assets_pb2'
  ,
  __doc__ = """Representation of a cloud resource.
  
  
  Attributes:
      version:
          The API version. Example: "v1".
      discovery_document_uri:
          The URL of the discovery document containing the resource's
          JSON schema. Example: "https://www.googleapis.com/discovery/v1
          /apis/compute/v1/rest". It will be left unspecified for
          resources without a discovery-based API, such as Cloud
          Bigtable.
      discovery_name:
          The JSON schema name listed in the discovery document.
          Example: "Project". It will be left unspecified for resources
          (such as Cloud Bigtable) without a discovery-based API.
      resource_url:
          The REST URL for accessing the resource. An HTTP GET operation
          using this URL returns the resource itself. Example:
          ``https://cloudresourcemanager.googleapis.com/v1/projects/my-
          project-123``. It will be left unspecified for resources
          without a REST API.
      parent:
          The full name of the immediate parent of this resource. See: h
          ttps://cloud.google.com/apis/design/resource\_names#full\_reso
          urce\_name  For GCP assets, it is the parent resource defined
          in the IAM policy hierarchy:
          https://cloud.google.com/iam/docs/overview#policy\_hierarchy.
          Example: "//cloudresourcemanager.googleapis.com/projects/my\_p
          roject\_123".  For third-party assets, it is up to the users
          to define.
      data:
          The content of the resource, in which some sensitive fields
          are scrubbed away and may not be present.
  """,
  # @@protoc_insertion_point(class_scope:google.cloud.asset.v1beta1.Resource)
  ))
_sym_db.RegisterMessage(Resource)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n\036com.google.cloud.asset.v1beta1B\nAssetProtoP\001Z?google.golang.org/genproto/googleapis/cloud/asset/v1beta1;asset\252\002\032Google.Cloud.Asset.V1Beta1\312\002\032Google\\Cloud\\Asset\\V1beta1'))
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2018 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Accesses the google.cloud.asset.v1beta1 AssetService API."""

import pkg_resources
import warnings

from google.oauth2 import service_account
import google.api_core.gapic_v1.client_info
import google.api_core.gapic_v1.config
import google.api_core.gapic_v1.method
import google.api_core.grpc_helpers
import google.api_core.operation
import google.api_core.operations_v1
import google.api_core.path_template
import grpc

from google.cloud.asset_v1beta1.gapic import asset_service_client_config
from google.cloud.asset_v1beta1.gapic import enums
from google.cloud.asset_v1beta1.gapic.transports import asset_service_grpc_transport
from google.cloud.asset_v1beta1.proto import asset_service_pb2
from google.cloud.asset_v1beta1.proto import asset_service_pb2_grpc
from google.cloud.asset_v1beta1.proto import assets_pb2
from google.longrunning import operations_pb2
from google.protobuf import timestamp_pb2

_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution(
    'google-cloud-asset', ).version


class AssetServiceClient(object):
    """Asset service definition."""

    SERVICE_ADDRESS = 'cloudasset.googleapis.com:443'
    """The default address of the service."""

    # The name of the interface for this client. This is the key used to
    # find the method configuration in the client_config dictionary.
    _INTERFACE_NAME = 'google.cloud.asset.v1beta1.AssetService'

    @classmethod
    def from_service_account_file(cls, filename, *args, **kwargs):
        """Creates an instance of this client using the provided credentials
        file.

        Args:
            filename (str): The path to the service account private key json
                file.
            args: Additional arguments to pass to the constructor.
            kwargs: Additional arguments to pass to the constructor.

        Returns:
            AssetServiceClient: The constructed client.
        """
        credentials = service_account.Credentials.from_service_account_file(
            filename)
        kwargs['credentials'] = credentials
        return cls(*args, **kwargs)

    from_service_account_json = from_service_account_file

    @classmethod
    def project_path(cls, project):
        """Return a fully-qualified project string."""
        return google.api_core.path_template.expand(
            'projects/{project}',
            project=project,
        )

    def __init__(self,
                 transport=None,
                 channel=None,
                 credentials=None,
                 client_config=asset_service_client_config.config,
                 client_info=None):
        """Constructor.

        Args:
            transport (Union[~.AssetServiceGrpcTransport,
                    Callable[[~.Credentials, type], ~.AssetServiceGrpcTransport]): A transport
                instance, responsible for actually making the API calls.
                The default transport uses the gRPC protocol.
                This argument may also be a callable which returns a
                transport instance. Callables will be sent the credentials
                as the first argument and the default transport class as
                the second argument.
            channel (grpc.Channel): DEPRECATED. A ``Channel`` instance
                through which to make calls. This argument is mutually exclusive
                with ``credentials``; providing both will raise an exception.
            credentials (google.auth.credentials.Credentials): The
                authorization credentials to attach to requests. These
                credentials identify this application to the service. If none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
                This argument is mutually exclusive with providing a
                transport instance to ``transport``; doing so will raise
                an exception.
            client_config (dict): DEPRECATED. A dictionary of call options for
                each method. If not specified, the default configuration is used.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
        """
        # Raise deprecation warnings for things we want to go away.
        if client_config:
            warnings.warn('The `client_config` argument is deprecated.',
                          PendingDeprecationWarning)
        if channel:
            warnings.warn(
                'The `channel` argument is deprecated; use '
                '`transport` instead.', PendingDeprecationWarning)

        # Instantiate the transport.
        # The transport is responsible for handling serialization and
        # deserialization and actually sending data to the service.
        if transport:
            if callable(transport):
                self.transport = transport(
                    credentials=credentials,
                    default_class=asset_service_grpc_transport.
                    AssetServiceGrpcTransport,
                )
            else:
                if credentials:
                    raise ValueError(
                        'Received both a transport instance and '
                        'credentials; these are mutually exclusive.')
                self.transport = transport
        else:
            self.transport = asset_service_grpc_transport.AssetServiceGrpcTransport(
                address=self.SERVICE_ADDRESS,
                channel=channel,
                credentials=credentials,
            )

        if client_info is None:
            client_info = (
                google.api_core.gapic_v1.client_info.DEFAULT_CLIENT_INFO)
        client_info.gapic_version = _GAPIC_LIBRARY_VERSION
        self._client_info = client_info

        # Parse out the default settings for retry and timeout for each RPC
        # from the client configuration.
        # (Ordinarily, these are the defaults specified in the `*_config.py`
        # file next to this one.)
        self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
            client_config['interfaces'][self._INTERFACE_NAME], )

        # Save a dictionary of cached API call functions.
        # These are the actual callables which invoke the proper
        # transport methods, wrapped with `wrap_method` to add retry,
        # timeout, and the like.
        self._inner_api_calls = {}

    # Service calls
    def export_assets(self,
                      parent,
                      output_config,
                      read_time=None,
                      asset_types=None,
                      content_type=None,
                      retry=google.api_core.gapic_v1.method.DEFAULT,
                      timeout=google.api_core.gapic_v1.method.DEFAULT,
                      metadata=None):
        """
        Exports assets with time and resource types to a given Google Cloud Storage
        location. The output format is newline-delimited JSON.
        This API implements the ``google.longrunning.Operation`` API allowing users
        to keep track of the export.

        Example:
            >>> from google.cloud import asset_v1beta1
            >>>
            >>> client = asset_v1beta1.AssetServiceClient()
            >>>
            >>> parent = client.project_path('[PROJECT]')
            >>>
            >>> # TODO: Initialize ``output_config``:
            >>> output_config = {}
            >>>
            >>> response = client.export_assets(parent, output_config)
            >>>
            >>> def callback(operation_future):
            ...     # Handle result.
            ...     result = operation_future.result()
            >>>
            >>> response.add_done_callback(callback)
            >>>
            >>> # Handle metadata.
            >>> metadata = response.metadata()

        Args:
            parent (str): Required. The relative name of the root asset. Can only be an organization
                number (such as \"organizations/123\"), or a project id (such as
                \"projects/my-project-id\") or a project number (such as \"projects/12345\").
            output_config (Union[dict, ~google.cloud.asset_v1beta1.types.OutputConfig]): Required. Output configuration indicating where the results will be output
                to. All results will be in newline delimited JSON format.
                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.asset_v1beta1.types.OutputConfig`
            read_time (Union[dict, ~google.cloud.asset_v1beta1.types.Timestamp]): Timestamp to take an asset snapshot. This can only be set to a timestamp in
                the past or of the current time. If not specified, the current time will be
                used. Due to delays in resource data collection and indexing, there is a
                volatile window during which running the same query may get different
                results.
                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.asset_v1beta1.types.Timestamp`
            asset_types (list[str]): A list of asset types of which to take a snapshot for. Example:
                \"google.compute.disk\". If specified, only matching assets will be returned.
            content_type (~google.cloud.asset_v1beta1.types.ContentType): Asset content type. If not specified, no content but the asset name will be
                returned.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.asset_v1beta1.types._OperationFuture` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'export_assets' not in self._inner_api_calls:
            self._inner_api_calls[
                'export_assets'] = google.api_core.gapic_v1.method.wrap_method(
                    self.transport.export_assets,
                    default_retry=self._method_configs['ExportAssets'].retry,
                    default_timeout=self._method_configs['ExportAssets'].
                    timeout,
                    client_info=self._client_info,
                )

        request = asset_service_pb2.ExportAssetsRequest(
            parent=parent,
            output_config=output_config,
            read_time=read_time,
            asset_types=asset_types,
            content_type=content_type,
        )
        operation = self._inner_api_calls['export_assets'](
            request, retry=retry, timeout=timeout, metadata=metadata)
        return google.api_core.operation.from_gapic(
            operation,
            self.transport._operations_client,
            asset_service_pb2.ExportAssetsResponse,
            metadata_type=asset_service_pb2.ExportAssetsRequest,
        )

    def batch_get_assets_history(
            self,
            parent,
            content_type,
            read_time_window,
            asset_names=None,
            retry=google.api_core.gapic_v1.method.DEFAULT,
            timeout=google.api_core.gapic_v1.method.DEFAULT,
            metadata=None):
        """
        Batch gets assets update history that overlaps a time window.
        For RESOURCE content, this API outputs history with asset in both
        non-delete or deleted status.
        For IAM_POLICY content, this API only outputs history when asset and its
        attached IAM POLICY both exist. So there may be gaps in the output history.

        Example:
            >>> from google.cloud import asset_v1beta1
            >>> from google.cloud.asset_v1beta1 import enums
            >>>
            >>> client = asset_v1beta1.AssetServiceClient()
            >>>
            >>> parent = client.project_path('[PROJECT]')
            >>>
            >>> # TODO: Initialize ``content_type``:
            >>> content_type = enums.ContentType.CONTENT_TYPE_UNSPECIFIED
            >>>
            >>> # TODO: Initialize ``read_time_window``:
            >>> read_time_window = {}
            >>>
            >>> response = client.batch_get_assets_history(parent, content_type, read_time_window)

        Args:
            parent (str): Required. The relative name of the root asset. It can only be an
                organization number (such as \"organizations/123\"), or a project id (such as
                \"projects/my-project-id\")\"or a project number (such as \"projects/12345\").
            content_type (~google.cloud.asset_v1beta1.types.ContentType): Required. The content type.
            read_time_window (Union[dict, ~google.cloud.asset_v1beta1.types.TimeWindow]): Required. The time window for the asset history. The start time is
                required. The returned results contain all temporal assets whose time
                window overlap with read_time_window.
                If a dict is provided, it must be of the same form as the protobuf
                message :class:`~google.cloud.asset_v1beta1.types.TimeWindow`
            asset_names (list[str]): A list of the full names of the assets. See:
                https://cloud.google.com/apis/design/resource_names#full_resource_name
                Example:
                \"//compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1\".

                The request becomes a no-op if the asset name list is empty, and the max
                size of the asset name list is 100 in one request.
            retry (Optional[google.api_core.retry.Retry]):  A retry object used
                to retry requests. If ``None`` is specified, requests will not
                be retried.
            timeout (Optional[float]): The amount of time, in seconds, to wait
                for the request to complete. Note that if ``retry`` is
                specified, the timeout applies to each individual attempt.
            metadata (Optional[Sequence[Tuple[str, str]]]): Additional metadata
                that is provided to the method.

        Returns:
            A :class:`~google.cloud.asset_v1beta1.types.BatchGetAssetsHistoryResponse` instance.

        Raises:
            google.api_core.exceptions.GoogleAPICallError: If the request
                    failed for any reason.
            google.api_core.exceptions.RetryError: If the request failed due
                    to a retryable error and retry attempts failed.
            ValueError: If the parameters are invalid.
        """
        # Wrap the transport method to add retry and timeout logic.
        if 'batch_get_assets_history' not in self._inner_api_calls:
            self._inner_api_calls[
                'batch_get_assets_history'] = google.api_core.gapic_v1.method.wrap_method(
                    self.transport.batch_get_assets_history,
                    default_retry=self.
                    _method_configs['BatchGetAssetsHistory'].retry,
                    default_timeout=self.
                    _method_configs['BatchGetAssetsHistory'].timeout,
                    client_info=self._client_info,
                )

        request = asset_service_pb2.BatchGetAssetsHistoryRequest(
            parent=parent,
            content_type=content_type,
            read_time_window=read_time_window,
            asset_names=asset_names,
        )
        return self._inner_api_calls['batch_get_assets_history'](
            request, retry=retry, timeout=timeout, metadata=metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.asset_v1beta1.proto import asset_service_pb2 as google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_asset__service__pb2
from google.longrunning import operations_pb2 as google_dot_longrunning_dot_operations__pb2


class AssetServiceStub(object):
  """Asset service definition.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.ExportAssets = channel.unary_unary(
        '/google.cloud.asset.v1beta1.AssetService/ExportAssets',
        request_serializer=google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_asset__service__pb2.ExportAssetsRequest.SerializeToString,
        response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
    self.BatchGetAssetsHistory = channel.unary_unary(
        '/google.cloud.asset.v1beta1.AssetService/BatchGetAssetsHistory',
        request_serializer=google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_asset__service__pb2.BatchGetAssetsHistoryRequest.SerializeToString,
        response_deserializer=google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_asset__service__pb2.BatchGetAssetsHistoryResponse.FromString,
        )


class AssetServiceServicer(object):
  """Asset service definition.
  """

  def ExportAssets(self, request, context):
    """Exports assets with time and resource types to a given Google Cloud Storage
    location. The output format is newline-delimited JSON.
    This API implements the [google.longrunning.Operation][google.longrunning.Operation] API allowing users
    to keep track of the export.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def BatchGetAssetsHistory(self, request, context):
    """Batch gets assets update history that overlaps a time window.
    For RESOURCE content, this API outputs history with asset in both
    non-delete or deleted status.
    For IAM_POLICY content, this API only outputs history when asset and its
    attached IAM POLICY both exist. So there may be gaps in the output history.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AssetServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'ExportAssets': grpc.unary_unary_rpc_method_handler(
          servicer.ExportAssets,
          request_deserializer=google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_asset__service__pb2.ExportAssetsRequest.FromString,
          response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
      ),
      'BatchGetAssetsHistory': grpc.unary_unary_rpc_method_handler(
          servicer.BatchGetAssetsHistory,
          request_deserializer=google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_asset__service__pb2.BatchGetAssetsHistoryRequest.FromString,
          response_serializer=google_dot_cloud_dot_asset__v1beta1_dot_proto_dot_asset__service__pb2.BatchGetAssetsHistoryResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.cloud.asset.v1beta1.AssetService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
